@@ -1,5 +1,7 @@
+import re
 import time
 from collections import namedtuple
+
 import psutil
 
 netstat = namedtuple('netstat', 'rx tx')
@@ -9,13 +11,12 @@ def make_netstat(old_stats, new_stats, timediff):
     tx = (new_stats.bytes_sent - old_stats.bytes_sent) / timediff
     return netstat(rx, tx)
 
-def active_devices(stats):
-    for key in stats:
-        if key == 'lo':
-            continue
-        if stats[key].bytes_recv == 0 and stats[key].bytes_sent == 0:
-            continue
-        yield key
+def is_valid_device(name, stat):
+    if not re.fullmatch(r"en\d+|enp\d+s\d|wlp\d+s\d+f\d+", name):
+        return False
+    if stat.bytes_recv == 0 and stat.bytes_sent == 0:
+        return False
+    return True
 
 class NetworkStat:
     def __init__(self):
@@ -27,7 +28,7 @@ class NetworkStat:
 
     def setup(self):
         self._update()
-        self.keys = list(active_devices(self._stats))
+        self.keys = sorted(self._stats.keys())
 
     def update(self):
         old_stats, old_time = self._stats, self._time
@@ -41,5 +42,7 @@ class NetworkStat:
         }
 
     def _update(self):
-        self._stats = psutil.net_io_counters(pernic=True)
+        self._stats = {
+            k: v for k, v in psutil.net_io_counters(pernic=True).items() if is_valid_device(k, v)
+        }
         self._time = time.time()
